#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'variable-editor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.i686/src/octave-5.1.0/libgui/src/variable-editor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'variable-editor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__variable_dock_widget_t {
    QByteArrayData data[16];
    char stringdata0[217];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__variable_dock_widget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__variable_dock_widget_t qt_meta_stringdata_octave__variable_dock_widget = {
    {
QT_MOC_LITERAL(0, 0, 28), // "octave::variable_dock_widget"
QT_MOC_LITERAL(1, 29, 23), // "variable_focused_signal"
QT_MOC_LITERAL(2, 53, 0), // ""
QT_MOC_LITERAL(3, 54, 4), // "name"
QT_MOC_LITERAL(4, 59, 19), // "queue_unfloat_float"
QT_MOC_LITERAL(5, 79, 11), // "queue_float"
QT_MOC_LITERAL(6, 91, 19), // "handle_focus_change"
QT_MOC_LITERAL(7, 111, 8), // "QWidget*"
QT_MOC_LITERAL(8, 120, 3), // "old"
QT_MOC_LITERAL(9, 124, 3), // "now"
QT_MOC_LITERAL(10, 128, 15), // "change_floating"
QT_MOC_LITERAL(11, 144, 16), // "change_existence"
QT_MOC_LITERAL(12, 161, 15), // "toplevel_change"
QT_MOC_LITERAL(13, 177, 17), // "change_fullscreen"
QT_MOC_LITERAL(14, 195, 13), // "unfloat_float"
QT_MOC_LITERAL(15, 209, 7) // "refloat"

    },
    "octave::variable_dock_widget\0"
    "variable_focused_signal\0\0name\0"
    "queue_unfloat_float\0queue_float\0"
    "handle_focus_change\0QWidget*\0old\0now\0"
    "change_floating\0change_existence\0"
    "toplevel_change\0change_fullscreen\0"
    "unfloat_float\0refloat"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__variable_dock_widget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       4,    0,   67,    2, 0x06 /* Public */,
       5,    0,   68,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    2,   69,    2, 0x0a /* Public */,
      10,    1,   74,    2, 0x08 /* Private */,
      11,    1,   77,    2, 0x08 /* Private */,
      12,    1,   80,    2, 0x08 /* Private */,
      13,    0,   83,    2, 0x08 /* Private */,
      14,    0,   84,    2, 0x09 /* Protected */,
      15,    0,   85,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 7,    8,    9,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::variable_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        variable_dock_widget *_t = static_cast<variable_dock_widget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->variable_focused_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->queue_unfloat_float(); break;
        case 2: _t->queue_float(); break;
        case 3: _t->handle_focus_change((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2]))); break;
        case 4: _t->change_floating((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->change_existence((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->toplevel_change((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->change_fullscreen(); break;
        case 8: _t->unfloat_float(); break;
        case 9: _t->refloat(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (variable_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_dock_widget::variable_focused_signal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (variable_dock_widget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_dock_widget::queue_unfloat_float)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (variable_dock_widget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_dock_widget::queue_float)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject octave::variable_dock_widget::staticMetaObject = {
    { &label_dock_widget::staticMetaObject, qt_meta_stringdata_octave__variable_dock_widget.data,
      qt_meta_data_octave__variable_dock_widget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::variable_dock_widget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::variable_dock_widget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__variable_dock_widget.stringdata0))
        return static_cast<void*>(this);
    return label_dock_widget::qt_metacast(_clname);
}

int octave::variable_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = label_dock_widget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void octave::variable_dock_widget::variable_focused_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void octave::variable_dock_widget::queue_unfloat_float()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void octave::variable_dock_widget::queue_float()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
struct qt_meta_stringdata_octave__variable_editor_stack_t {
    QByteArrayData data[12];
    char stringdata0[128];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__variable_editor_stack_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__variable_editor_stack_t qt_meta_stringdata_octave__variable_editor_stack = {
    {
QT_MOC_LITERAL(0, 0, 29), // "octave::variable_editor_stack"
QT_MOC_LITERAL(1, 30, 14), // "command_signal"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 3), // "cmd"
QT_MOC_LITERAL(4, 50, 20), // "edit_variable_signal"
QT_MOC_LITERAL(5, 71, 4), // "name"
QT_MOC_LITERAL(6, 76, 12), // "octave_value"
QT_MOC_LITERAL(7, 89, 3), // "val"
QT_MOC_LITERAL(8, 93, 12), // "set_editable"
QT_MOC_LITERAL(9, 106, 8), // "editable"
QT_MOC_LITERAL(10, 115, 7), // "levelUp"
QT_MOC_LITERAL(11, 123, 4) // "save"

    },
    "octave::variable_editor_stack\0"
    "command_signal\0\0cmd\0edit_variable_signal\0"
    "name\0octave_value\0val\0set_editable\0"
    "editable\0levelUp\0save"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__variable_editor_stack[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,
       4,    2,   42,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   47,    2, 0x0a /* Public */,
      10,    0,   50,    2, 0x0a /* Public */,
      11,    0,   51,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 6,    5,    7,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::variable_editor_stack::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        variable_editor_stack *_t = static_cast<variable_editor_stack *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->command_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->edit_variable_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const octave_value(*)>(_a[2]))); break;
        case 2: _t->set_editable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->levelUp(); break;
        case 4: _t->save(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (variable_editor_stack::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor_stack::command_signal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (variable_editor_stack::*_t)(const QString & , const octave_value & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor_stack::edit_variable_signal)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject octave::variable_editor_stack::staticMetaObject = {
    { &QStackedWidget::staticMetaObject, qt_meta_stringdata_octave__variable_editor_stack.data,
      qt_meta_data_octave__variable_editor_stack,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::variable_editor_stack::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::variable_editor_stack::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__variable_editor_stack.stringdata0))
        return static_cast<void*>(this);
    return QStackedWidget::qt_metacast(_clname);
}

int octave::variable_editor_stack::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStackedWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void octave::variable_editor_stack::command_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void octave::variable_editor_stack::edit_variable_signal(const QString & _t1, const octave_value & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_octave__variable_editor_view_t {
    QByteArrayData data[26];
    char stringdata0[398];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__variable_editor_view_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__variable_editor_view_t qt_meta_stringdata_octave__variable_editor_view = {
    {
QT_MOC_LITERAL(0, 0, 28), // "octave::variable_editor_view"
QT_MOC_LITERAL(1, 29, 14), // "command_signal"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 3), // "cmd"
QT_MOC_LITERAL(4, 49, 23), // "add_edit_actions_signal"
QT_MOC_LITERAL(5, 73, 6), // "QMenu*"
QT_MOC_LITERAL(6, 80, 4), // "menu"
QT_MOC_LITERAL(7, 85, 16), // "qualifier_string"
QT_MOC_LITERAL(8, 102, 14), // "createVariable"
QT_MOC_LITERAL(9, 117, 16), // "transposeContent"
QT_MOC_LITERAL(10, 134, 14), // "range_selected"
QT_MOC_LITERAL(11, 149, 10), // "QList<int>"
QT_MOC_LITERAL(12, 160, 15), // "delete_selected"
QT_MOC_LITERAL(13, 176, 12), // "clearContent"
QT_MOC_LITERAL(14, 189, 12), // "cutClipboard"
QT_MOC_LITERAL(15, 202, 13), // "copyClipboard"
QT_MOC_LITERAL(16, 216, 14), // "pasteClipboard"
QT_MOC_LITERAL(17, 231, 31), // "handle_horizontal_scroll_action"
QT_MOC_LITERAL(18, 263, 6), // "action"
QT_MOC_LITERAL(19, 270, 29), // "handle_vertical_scroll_action"
QT_MOC_LITERAL(20, 300, 17), // "createContextMenu"
QT_MOC_LITERAL(21, 318, 2), // "pt"
QT_MOC_LITERAL(22, 321, 16), // "createColumnMenu"
QT_MOC_LITERAL(23, 338, 13), // "createRowMenu"
QT_MOC_LITERAL(24, 352, 18), // "selected_to_octave"
QT_MOC_LITERAL(25, 371, 26) // "selected_command_requested"

    },
    "octave::variable_editor_view\0"
    "command_signal\0\0cmd\0add_edit_actions_signal\0"
    "QMenu*\0menu\0qualifier_string\0"
    "createVariable\0transposeContent\0"
    "range_selected\0QList<int>\0delete_selected\0"
    "clearContent\0cutClipboard\0copyClipboard\0"
    "pasteClipboard\0handle_horizontal_scroll_action\0"
    "action\0handle_vertical_scroll_action\0"
    "createContextMenu\0pt\0createColumnMenu\0"
    "createRowMenu\0selected_to_octave\0"
    "selected_command_requested"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__variable_editor_view[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   99,    2, 0x06 /* Public */,
       4,    2,  102,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,  107,    2, 0x0a /* Public */,
       9,    0,  108,    2, 0x0a /* Public */,
      10,    0,  109,    2, 0x0a /* Public */,
      12,    0,  110,    2, 0x0a /* Public */,
      13,    0,  111,    2, 0x0a /* Public */,
      14,    0,  112,    2, 0x0a /* Public */,
      15,    0,  113,    2, 0x0a /* Public */,
      16,    0,  114,    2, 0x0a /* Public */,
      17,    1,  115,    2, 0x0a /* Public */,
      19,    1,  118,    2, 0x0a /* Public */,
      20,    1,  121,    2, 0x0a /* Public */,
      22,    1,  124,    2, 0x0a /* Public */,
      23,    1,  127,    2, 0x0a /* Public */,
      24,    0,  130,    2, 0x0a /* Public */,
      25,    1,  131,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 5, QMetaType::QString,    6,    7,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   18,
    QMetaType::Void, QMetaType::Int,   18,
    QMetaType::Void, QMetaType::QPoint,   21,
    QMetaType::Void, QMetaType::QPoint,   21,
    QMetaType::Void, QMetaType::QPoint,   21,
    QMetaType::QString,
    QMetaType::Void, QMetaType::QString,    3,

       0        // eod
};

void octave::variable_editor_view::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        variable_editor_view *_t = static_cast<variable_editor_view *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->command_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->add_edit_actions_signal((*reinterpret_cast< QMenu*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->createVariable(); break;
        case 3: _t->transposeContent(); break;
        case 4: { QList<int> _r = _t->range_selected();
            if (_a[0]) *reinterpret_cast< QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->delete_selected(); break;
        case 6: _t->clearContent(); break;
        case 7: _t->cutClipboard(); break;
        case 8: _t->copyClipboard(); break;
        case 9: _t->pasteClipboard(); break;
        case 10: _t->handle_horizontal_scroll_action((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->handle_vertical_scroll_action((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->createContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 13: _t->createColumnMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 14: _t->createRowMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 15: { QString _r = _t->selected_to_octave();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->selected_command_requested((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (variable_editor_view::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor_view::command_signal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (variable_editor_view::*_t)(QMenu * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor_view::add_edit_actions_signal)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject octave::variable_editor_view::staticMetaObject = {
    { &QTableView::staticMetaObject, qt_meta_stringdata_octave__variable_editor_view.data,
      qt_meta_data_octave__variable_editor_view,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::variable_editor_view::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::variable_editor_view::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__variable_editor_view.stringdata0))
        return static_cast<void*>(this);
    return QTableView::qt_metacast(_clname);
}

int octave::variable_editor_view::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTableView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void octave::variable_editor_view::command_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void octave::variable_editor_view::add_edit_actions_signal(QMenu * _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_octave__HoverToolButton_t {
    QByteArrayData data[4];
    char stringdata0[59];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__HoverToolButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__HoverToolButton_t qt_meta_stringdata_octave__HoverToolButton = {
    {
QT_MOC_LITERAL(0, 0, 23), // "octave::HoverToolButton"
QT_MOC_LITERAL(1, 24, 14), // "hovered_signal"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 18) // "popup_shown_signal"

    },
    "octave::HoverToolButton\0hovered_signal\0"
    "\0popup_shown_signal"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__HoverToolButton[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,
       3,    0,   25,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::HoverToolButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        HoverToolButton *_t = static_cast<HoverToolButton *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->hovered_signal(); break;
        case 1: _t->popup_shown_signal(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (HoverToolButton::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HoverToolButton::hovered_signal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (HoverToolButton::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HoverToolButton::popup_shown_signal)) {
                *result = 1;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject octave::HoverToolButton::staticMetaObject = {
    { &QToolButton::staticMetaObject, qt_meta_stringdata_octave__HoverToolButton.data,
      qt_meta_data_octave__HoverToolButton,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::HoverToolButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::HoverToolButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__HoverToolButton.stringdata0))
        return static_cast<void*>(this);
    return QToolButton::qt_metacast(_clname);
}

int octave::HoverToolButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QToolButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void octave::HoverToolButton::hovered_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void octave::HoverToolButton::popup_shown_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
struct qt_meta_stringdata_octave__ReturnFocusToolButton_t {
    QByteArrayData data[3];
    char stringdata0[49];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__ReturnFocusToolButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__ReturnFocusToolButton_t qt_meta_stringdata_octave__ReturnFocusToolButton = {
    {
QT_MOC_LITERAL(0, 0, 29), // "octave::ReturnFocusToolButton"
QT_MOC_LITERAL(1, 30, 17), // "about_to_activate"
QT_MOC_LITERAL(2, 48, 0) // ""

    },
    "octave::ReturnFocusToolButton\0"
    "about_to_activate\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__ReturnFocusToolButton[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

       0        // eod
};

void octave::ReturnFocusToolButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ReturnFocusToolButton *_t = static_cast<ReturnFocusToolButton *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->about_to_activate(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ReturnFocusToolButton::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ReturnFocusToolButton::about_to_activate)) {
                *result = 0;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject octave::ReturnFocusToolButton::staticMetaObject = {
    { &HoverToolButton::staticMetaObject, qt_meta_stringdata_octave__ReturnFocusToolButton.data,
      qt_meta_data_octave__ReturnFocusToolButton,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::ReturnFocusToolButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::ReturnFocusToolButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__ReturnFocusToolButton.stringdata0))
        return static_cast<void*>(this);
    return HoverToolButton::qt_metacast(_clname);
}

int octave::ReturnFocusToolButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = HoverToolButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void octave::ReturnFocusToolButton::about_to_activate()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_octave__ReturnFocusMenu_t {
    QByteArrayData data[3];
    char stringdata0[43];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__ReturnFocusMenu_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__ReturnFocusMenu_t qt_meta_stringdata_octave__ReturnFocusMenu = {
    {
QT_MOC_LITERAL(0, 0, 23), // "octave::ReturnFocusMenu"
QT_MOC_LITERAL(1, 24, 17), // "about_to_activate"
QT_MOC_LITERAL(2, 42, 0) // ""

    },
    "octave::ReturnFocusMenu\0about_to_activate\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__ReturnFocusMenu[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

       0        // eod
};

void octave::ReturnFocusMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ReturnFocusMenu *_t = static_cast<ReturnFocusMenu *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->about_to_activate(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ReturnFocusMenu::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ReturnFocusMenu::about_to_activate)) {
                *result = 0;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject octave::ReturnFocusMenu::staticMetaObject = {
    { &QMenu::staticMetaObject, qt_meta_stringdata_octave__ReturnFocusMenu.data,
      qt_meta_data_octave__ReturnFocusMenu,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::ReturnFocusMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::ReturnFocusMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__ReturnFocusMenu.stringdata0))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int octave::ReturnFocusMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void octave::ReturnFocusMenu::about_to_activate()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_octave__variable_editor_t {
    QByteArrayData data[34];
    char stringdata0[500];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__variable_editor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__variable_editor_t qt_meta_stringdata_octave__variable_editor = {
    {
QT_MOC_LITERAL(0, 0, 23), // "octave::variable_editor"
QT_MOC_LITERAL(1, 24, 7), // "updated"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 8), // "finished"
QT_MOC_LITERAL(4, 42, 14), // "command_signal"
QT_MOC_LITERAL(5, 57, 3), // "cmd"
QT_MOC_LITERAL(6, 61, 14), // "refresh_signal"
QT_MOC_LITERAL(7, 76, 20), // "clear_content_signal"
QT_MOC_LITERAL(8, 97, 21), // "copy_clipboard_signal"
QT_MOC_LITERAL(9, 119, 22), // "paste_clipboard_signal"
QT_MOC_LITERAL(10, 142, 15), // "level_up_signal"
QT_MOC_LITERAL(11, 158, 11), // "save_signal"
QT_MOC_LITERAL(12, 170, 22), // "delete_selected_signal"
QT_MOC_LITERAL(13, 193, 23), // "selected_command_signal"
QT_MOC_LITERAL(14, 217, 10), // "callUpdate"
QT_MOC_LITERAL(15, 228, 15), // "notice_settings"
QT_MOC_LITERAL(16, 244, 16), // "const QSettings*"
QT_MOC_LITERAL(17, 261, 13), // "edit_variable"
QT_MOC_LITERAL(18, 275, 4), // "name"
QT_MOC_LITERAL(19, 280, 12), // "octave_value"
QT_MOC_LITERAL(20, 293, 3), // "val"
QT_MOC_LITERAL(21, 297, 18), // "variable_destroyed"
QT_MOC_LITERAL(22, 316, 3), // "obj"
QT_MOC_LITERAL(23, 320, 16), // "variable_focused"
QT_MOC_LITERAL(24, 337, 29), // "record_hovered_focus_variable"
QT_MOC_LITERAL(25, 367, 30), // "restore_hovered_focus_variable"
QT_MOC_LITERAL(26, 398, 10), // "closeEvent"
QT_MOC_LITERAL(27, 409, 12), // "QCloseEvent*"
QT_MOC_LITERAL(28, 422, 4), // "save"
QT_MOC_LITERAL(29, 427, 12), // "cutClipboard"
QT_MOC_LITERAL(30, 440, 13), // "copyClipboard"
QT_MOC_LITERAL(31, 454, 14), // "pasteClipboard"
QT_MOC_LITERAL(32, 469, 7), // "levelUp"
QT_MOC_LITERAL(33, 477, 22) // "relay_selected_command"

    },
    "octave::variable_editor\0updated\0\0"
    "finished\0command_signal\0cmd\0refresh_signal\0"
    "clear_content_signal\0copy_clipboard_signal\0"
    "paste_clipboard_signal\0level_up_signal\0"
    "save_signal\0delete_selected_signal\0"
    "selected_command_signal\0callUpdate\0"
    "notice_settings\0const QSettings*\0"
    "edit_variable\0name\0octave_value\0val\0"
    "variable_destroyed\0obj\0variable_focused\0"
    "record_hovered_focus_variable\0"
    "restore_hovered_focus_variable\0"
    "closeEvent\0QCloseEvent*\0save\0cutClipboard\0"
    "copyClipboard\0pasteClipboard\0levelUp\0"
    "relay_selected_command"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__variable_editor[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  139,    2, 0x06 /* Public */,
       3,    0,  140,    2, 0x06 /* Public */,
       4,    1,  141,    2, 0x06 /* Public */,
       6,    0,  144,    2, 0x06 /* Public */,
       7,    0,  145,    2, 0x06 /* Public */,
       8,    0,  146,    2, 0x06 /* Public */,
       9,    0,  147,    2, 0x06 /* Public */,
      10,    0,  148,    2, 0x06 /* Public */,
      11,    0,  149,    2, 0x06 /* Public */,
      12,    0,  150,    2, 0x06 /* Public */,
      13,    1,  151,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    2,  154,    2, 0x0a /* Public */,
      15,    1,  159,    2, 0x0a /* Public */,
      17,    2,  162,    2, 0x0a /* Public */,
      21,    1,  167,    2, 0x0a /* Public */,
      23,    1,  170,    2, 0x0a /* Public */,
      24,    0,  173,    2, 0x0a /* Public */,
      25,    0,  174,    2, 0x0a /* Public */,
      26,    1,  175,    2, 0x09 /* Protected */,
      28,    0,  178,    2, 0x09 /* Protected */,
      29,    0,  179,    2, 0x09 /* Protected */,
      30,    0,  180,    2, 0x09 /* Protected */,
      31,    0,  181,    2, 0x09 /* Protected */,
      32,    0,  182,    2, 0x09 /* Protected */,
      33,    1,  183,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,

 // slots: parameters
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    2,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 19,   18,   20,
    QMetaType::Void, QMetaType::QObjectStar,   22,
    QMetaType::Void, QMetaType::QString,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 27,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,

       0        // eod
};

void octave::variable_editor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        variable_editor *_t = static_cast<variable_editor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updated(); break;
        case 1: _t->finished(); break;
        case 2: _t->command_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->refresh_signal(); break;
        case 4: _t->clear_content_signal(); break;
        case 5: _t->copy_clipboard_signal(); break;
        case 6: _t->paste_clipboard_signal(); break;
        case 7: _t->level_up_signal(); break;
        case 8: _t->save_signal(); break;
        case 9: _t->delete_selected_signal(); break;
        case 10: _t->selected_command_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->callUpdate((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 12: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
        case 13: _t->edit_variable((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const octave_value(*)>(_a[2]))); break;
        case 14: _t->variable_destroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 15: _t->variable_focused((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: _t->record_hovered_focus_variable(); break;
        case 17: _t->restore_hovered_focus_variable(); break;
        case 18: _t->closeEvent((*reinterpret_cast< QCloseEvent*(*)>(_a[1]))); break;
        case 19: _t->save(); break;
        case 20: _t->cutClipboard(); break;
        case 21: _t->copyClipboard(); break;
        case 22: _t->pasteClipboard(); break;
        case 23: _t->levelUp(); break;
        case 24: _t->relay_selected_command((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (variable_editor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::updated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (variable_editor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::finished)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (variable_editor::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::command_signal)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (variable_editor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::refresh_signal)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (variable_editor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::clear_content_signal)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (variable_editor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::copy_clipboard_signal)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (variable_editor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::paste_clipboard_signal)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (variable_editor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::level_up_signal)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (variable_editor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::save_signal)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (variable_editor::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::delete_selected_signal)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (variable_editor::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&variable_editor::selected_command_signal)) {
                *result = 10;
                return;
            }
        }
    }
}

const QMetaObject octave::variable_editor::staticMetaObject = {
    { &octave_dock_widget::staticMetaObject, qt_meta_stringdata_octave__variable_editor.data,
      qt_meta_data_octave__variable_editor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::variable_editor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::variable_editor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__variable_editor.stringdata0))
        return static_cast<void*>(this);
    return octave_dock_widget::qt_metacast(_clname);
}

int octave::variable_editor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = octave_dock_widget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void octave::variable_editor::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void octave::variable_editor::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void octave::variable_editor::command_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void octave::variable_editor::refresh_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void octave::variable_editor::clear_content_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void octave::variable_editor::copy_clipboard_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void octave::variable_editor::paste_clipboard_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void octave::variable_editor::level_up_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void octave::variable_editor::save_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void octave::variable_editor::delete_selected_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void octave::variable_editor::selected_command_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
